compute_centroids_c: Aggregate categorical data within clusters

View source: R/db_kmeans.R

compute_centroids_cR Documentation

Aggregate categorical data within clusters

Description

Aggregate categorical data within clusters

Usage

compute_centroids_c(data = dat, cluster = NULL, ambiguous_cutoff = 0.5)

Arguments

data

A numeric matrix of data where cells correspond to rows and genes correspond to columns

ambiguous_cutoff

Proportion of the most represented category in a cluster. Clusters falling below this cutoff will be considered ambiguous.

Value

A list that includes the following elements:

cluster

A vector of length nrow(data) containing cluster assignments.

d

A vector of length nrow(data) containing density values.

Author(s)

Kevin Brulois


kbrulois/Dufy documentation built on May 4, 2022, 3:54 a.m.