compute_centroids_n: Aggregate numeric data within clusters

View source: R/db_kmeans.R

compute_centroids_nR Documentation

Aggregate numeric data within clusters

Description

Aggregate numeric data within clusters

Usage

compute_centroids_n(data = dat, cluster = NULL, centering_function = median)

Arguments

data

A numeric matrix of data where cells correspond to rows and genes correspond to columns

centering_function

A function used to aggregate data for a given gene within a given cluster

Value

A list that includes the following elements:

cluster

A vector of length nrow(data) containing cluster assignments.

d

A vector of length nrow(data) containing density values.

Author(s)

Kevin Brulois


kbrulois/Dufy documentation built on May 4, 2022, 3:54 a.m.