dbSpadeDownsample: A flexible version of SPADE's density-based downsampling...

View source: R/SPADEutilities.R

dbSpadeDownsampleR Documentation

A flexible version of SPADE's density-based downsampling function

Description

This is a version of SPADE's density-based downsampling function, adapted for use with standard R matrices instead of FCS files.

Usage

dbSpadeDownsample(
  data,
  d = NULL,
  target_number = 400,
  target_pctile = NULL,
  target_percent = NULL
)

Arguments

data

A numeric matrix of data where cells correspond to rows and genes correspond to columns

Value

A vector of indices corresponding to rows of data

Author(s)

Kevin Brulois


kbrulois/Dufy documentation built on May 4, 2022, 3:54 a.m.