graphicalDownsample: Graphically-based Downsampling

View source: R/graphicalDownsample.R

graphicalDownsampleR Documentation

Graphically-based Downsampling

Description

This method starts by constructing a lattice encompassing the data and identifies the points in the data that are closest to one of the lattice points. This is done iteratively and the distance between lattice points is adjusted until the number of closest data points is approximately equal to a user-specified target_number.

Usage

graphicalDownsample(
  data = dat,
  target_number = 400,
  iter_max = 100,
  label = ""
)

Arguments

data

A numeric matrix of data where cells correspond to rows and genes correspond to columns

target_number

The number of cells to downsample to

iter_max

The maximum number of iterations allowed.

label

(Optional) A label to be used in messages

Value

A list that includes the following elements:

indices

A vector of indices of data

lattice

A data.frame of lattice coordinates used to select data points

Author(s)

Kevin Brulois


kbrulois/Dufy documentation built on May 4, 2022, 3:54 a.m.