monocle3_leiden_wrapper: A resTuner-compatible wrapper function for leiden clustering...

View source: R/resTuner.R

monocle3_leiden_wrapperR Documentation

A resTuner-compatible wrapper function for leiden clustering using monocle3

Description

A resTuner-compatible wrapper function for leiden clustering using monocle3

Usage

monocle3_leiden_wrapper(input_data, resolution, k, ...)

Arguments

input_data

A matrix where features correspond to rows and cells correspond to columns.

resolution

Either a positive integer specifying the exact number of clusters desired or a vector of length two specifying range.

k

The number of rounds of clusterings to perform. Default: 5.

...

Arguments passed to monocle3:::leiden_clustering

Value

A vector of length ncol(input_data) containing cluster assignments.

Author(s)

Kevin Brulois


kbrulois/Dufy documentation built on May 4, 2022, 3:54 a.m.