optiDensity: Optimized version of SPADE's local density computation

View source: R/SPADEutilities.R

optiDensityR Documentation

Optimized version of SPADE's local density computation

Description

This function computes local density using the spade::SPADE.density function and a range of values for the kernel_mult and apprx_mult parameters. It then selects and returns the density with the greatest variance.

Usage

optiDensity(data, selection_method = c("ks.test", "variance"))

Arguments

data

A numeric matrix of data where cells correspond to rows

Value

A vector of density values corresponding to each row of data.

Author(s)

Kevin Brulois


kbrulois/Dufy documentation built on May 4, 2022, 3:54 a.m.