seurat_cluster_wrapper: A resTuner-compatible wrapper function for clustering using...

View source: R/resTuner.R

seurat_cluster_wrapperR Documentation

A resTuner-compatible wrapper function for clustering using Seurat

Description

A resTuner-compatible wrapper function for clustering using Seurat

Usage

seurat_cluster_wrapper(input_data, .resolution = 0.05, k = 5, ...)

Arguments

input_data

A matrix where features correspond to rows and cells correspond to columns.

k

The number of rounds of clusterings to perform. Default: 5.

...

Arguments passed to Seurat::FindClusters

resolution

Either a positive integer specifying the exact number of clusters desired or a vector of length two specifying range.

Value

A vector of length ncol(input_data) containing cluster assignments.

Author(s)

Kevin Brulois


kbrulois/Dufy documentation built on May 4, 2022, 3:54 a.m.