| compute_centroids_c | R Documentation |
Aggregate categorical data within clusters
compute_centroids_c(data = dat, cluster = NULL, ambiguous_cutoff = 0.5)
data |
A numeric matrix of data where cells correspond to rows and genes correspond to columns |
ambiguous_cutoff |
Proportion of the most represented category in a cluster. Clusters falling below this cutoff will be considered ambiguous. |
A list that includes the following elements:
A vector of length nrow(data) containing cluster assignments.
A vector of length nrow(data) containing density values.
Kevin Brulois
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.