| compute_centroids_n | R Documentation |
Aggregate numeric data within clusters
compute_centroids_n(data = dat, cluster = NULL, centering_function = median)
data |
A numeric matrix of data where cells correspond to rows and genes correspond to columns |
centering_function |
A function used to aggregate data for a given gene within a given cluster |
A list that includes the following elements:
A vector of length nrow(data) containing cluster assignments.
A vector of length nrow(data) containing density values.
Kevin Brulois
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.