View source: R/SPADEutilities.R
| dbSpadeDownsample | R Documentation |
This is a version of SPADE's density-based downsampling function, adapted for use with standard R matrices instead of FCS files.
dbSpadeDownsample( data, d = NULL, target_number = 400, target_pctile = NULL, target_percent = NULL )
data |
A numeric matrix of data where cells correspond to rows and genes correspond to columns |
A vector of indices corresponding to rows of data
Kevin Brulois
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.