| db_kmeans | R Documentation |
This algorithm performs k-means clustering and sub-clustering such that the size of each cluster is proportional to the local density. This is done iteratively and the initial size of the kmeans clusters is updated until the desired number of total clusters is reached.
db_kmeans(data = dat, clusters = 400, d = NULL, iter_max = 100, label = "")
data |
A numeric matrix of data where cells correspond to rows and genes correspond to columns |
clusters |
The number of clusters |
d |
A numeric vector of density values corresponding to rows of data. |
iter_max |
The maximum number of iterations allowed. |
label |
(Optional) A label to be prepended to cluster names and used in messages |
A list that includes the following elements:
A vector of length nrow(data) containing cluster assignments.
A vector of length nrow(data) containing density values.
Kevin Brulois
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.