View source: R/graphicalDownsample.R
| graphicalDownsample | R Documentation |
This method starts by constructing a lattice encompassing the data and identifies the points in the data that are closest to one of the lattice points. This is done iteratively and the distance between lattice points is adjusted until the number of closest data points is approximately equal to a user-specified target_number.
graphicalDownsample( data = dat, target_number = 400, iter_max = 100, label = "" )
data |
A numeric matrix of data where cells correspond to rows and genes correspond to columns |
target_number |
The number of cells to downsample to |
iter_max |
The maximum number of iterations allowed. |
label |
(Optional) A label to be used in messages |
A list that includes the following elements:
A vector of indices of data
A data.frame of lattice coordinates used to select data points
Kevin Brulois
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.