| monocle3_leiden_wrapper | R Documentation |
A resTuner-compatible wrapper function for leiden clustering using monocle3
monocle3_leiden_wrapper(input_data, resolution, k, ...)
input_data |
A matrix where features correspond to rows and cells correspond to columns. |
resolution |
Either a positive integer specifying the exact number of clusters desired or a vector of length two specifying range. |
k |
The number of rounds of clusterings to perform. Default: 5. |
... |
Arguments passed to monocle3:::leiden_clustering |
A vector of length ncol(input_data) containing cluster assignments.
Kevin Brulois
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.