View source: R/SPADEutilities.R
| optiDensity | R Documentation |
This function computes local density using the spade::SPADE.density function and a range of values for the kernel_mult and apprx_mult parameters. It then selects and returns the density with the greatest variance.
optiDensity(data, selection_method = c("ks.test", "variance"))
data |
A numeric matrix of data where cells correspond to rows |
A vector of density values corresponding to each row of data.
Kevin Brulois
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.