| seurat_cluster_wrapper | R Documentation |
A resTuner-compatible wrapper function for clustering using Seurat
seurat_cluster_wrapper(input_data, .resolution = 0.05, k = 5, ...)
input_data |
A matrix where features correspond to rows and cells correspond to columns. |
k |
The number of rounds of clusterings to perform. Default: 5. |
... |
Arguments passed to Seurat::FindClusters |
resolution |
Either a positive integer specifying the exact number of clusters desired or a vector of length two specifying range. |
A vector of length ncol(input_data) containing cluster assignments.
Kevin Brulois
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.